target <- 0.2; ndose <- 7
enter.times<- c(0, 0.266, 0.638, 1.54, 2.48, 3.14, 3.32, 4.01, 4.39, 5.38, 5.76,
6.54, 6.66, 6.93, 7.32, 7.66, 8.14, 8.74)
dlt.times<- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0.610, 0, 2.98, 0, 0, 1.95, 0, 0, 1.48)
current.t<- 9.41
doses<-c(1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4, 3, 3, 3, 4, 4, 4)
## determine the dose level for the next cohort using the TITE-CFO design
decision <- lateonset.next(design = 'TITE-CFO', target, ndose, currdose = 4, assess.window = 3,
enter.times, dlt.times, current.t, doses)
summary(decision)
## determine the dose level for the next cohort using the TITE-aCFO design
decision <- lateonset.next(design = 'TITE-aCFO', target, ndose, currdose = 4, assess.window = 3,
enter.times, dlt.times, current.t, doses)
summary(decision)
## determine the dose level for the next cohort using the f-CFO design
decision <- lateonset.next(design = 'fCFO', target, ndose, currdose = 4, assess.window = 3,
enter.times, dlt.times, current.t, doses)
summary(decision)
## determine the dose level for the next cohort using the f-aCFO design
decision <- lateonset.next(design = 'f-aCFO', target, ndose, currdose = 4, assess.window = 3,
enter.times, dlt.times, current.t, doses)
summary(decision)
## determine the dose level for the next cohort using the benchmark CFO design
decision <- lateonset.next(design = 'bCFO', target, ndose, currdose = 4, assess.window = 3,
enter.times, dlt.times, current.t, doses)
summary(decision)
## determine the dose level for the next cohort using the benchmark aCFO design
decision <- lateonset.next(design='b-aCFO', target, ndose, currdose = 4, assess.window = 3,
enter.times, dlt.times, current.t, doses)
summary(decision)
Run the code above in your browser using DataLab